@@ -28,16 +28,16 @@
 #define MISSING -1
 #define UNKNOWN -2
 
-FILE *logfile = NULL;
-FILE *outfile = NULL;
-FILE *missing_file = NULL;
-long long start_offset = 0;
-long long end_offset = 0;
-int quick = 0;
-int verbose = 0;
-int check_jigdo_header = 1;
-UINT64 out_size = 0;
-char *missing_filename = NULL;
+static FILE *logfile = NULL;
+static FILE *outfile = NULL;
+static FILE *missing_file = NULL;
+static long long start_offset = 0;
+static long long end_offset = 0;
+static int quick = 0;
+static int verbose = 0;
+static int check_jigdo_header = 1;
+static UINT64 out_size = 0;
+static char *missing_filename = NULL;
 
 typedef struct match_list_
 {
@@ -46,8 +46,8 @@ typedef struct match_list_
     char *mirror_path;
 } match_list_t;
 
-match_list_t *match_list_head = NULL;
-match_list_t *match_list_tail = NULL;
+static match_list_t *match_list_head = NULL;
+static match_list_t *match_list_tail = NULL;
 
 typedef struct md5_list_
 {
@@ -57,16 +57,10 @@ typedef struct md5_list_
     char *full_path;
 } md5_list_t;
 
-md5_list_t *md5_list_head = NULL;
-md5_list_t *md5_list_tail = NULL;
+static md5_list_t *md5_list_head = NULL;
+static md5_list_t *md5_list_tail = NULL;
 
-struct
-{
-    char   *data_buf;
-    INT64   buf_size;
-    INT64   offset_in_curr_buf;
-    INT64   total_offset;
-} zip_state;
+static zip_state_t zip_state;
 
 /* Grab the file component from a full path */
 static char *file_base_name(char *path)
@@ -428,7 +422,7 @@ static int add_file_entry(char *jigdo_entry)
 static int parse_jigdo_file(char *filename)
 {
     char buf[2048];
-    gzFile *file = NULL;
+    gzFile file = NULL;
     char *ret = NULL;
     int error = 0;
     int num_files = 0;
@@ -488,183 +482,6 @@ static int parse_jigdo_file(char *filename)
     return error;
 }
 
-static int ungzip_data_block(char *in_buf, INT64 in_len, char *out_buf, INT64 out_len)
-{
-    int error = 0;
-    z_stream uc_stream;
-    
-    uc_stream.zalloc = NULL;
-    uc_stream.zfree = NULL;
-    uc_stream.opaque = NULL;
-    uc_stream.next_in = (unsigned char *)in_buf;
-    uc_stream.avail_in = in_len;
-
-    error = inflateInit(&uc_stream);
-    if (Z_OK != error)
-    {
-        fprintf(logfile, "ungzip_data_block: failed to init, error %d\n", error);
-        return EIO;
-    }
-    
-    uc_stream.next_out = (unsigned char *)out_buf;
-    uc_stream.avail_out = out_len;
-
-    error = inflate(&uc_stream, Z_FINISH);
-    if (Z_OK != error && Z_STREAM_END != error)
-    {
-        fprintf(logfile, "ungzip_data_block: failed to decompress, error %d\n", error);
-        return EIO;
-    }
-    
-    error = inflateEnd(&uc_stream);
-    if (Z_OK != error)
-    {
-        fprintf(logfile, "ungzip_data_block: failed to end, error %d\n", error);
-        return EIO;
-    }
-    
-    return 0;
-}    
-
-static int unbzip2_data_block(char *in_buf, INT64 in_len, char *out_buf, INT64 out_len)
-{
-    int error = 0;
-    bz_stream uc_stream;
-    
-    uc_stream.bzalloc = NULL;
-    uc_stream.bzfree = NULL;
-    uc_stream.opaque = NULL;
-    uc_stream.next_in = in_buf;
-    uc_stream.avail_in = in_len;
-
-    error = BZ2_bzDecompressInit(&uc_stream, 0, 0);
-    if (BZ_OK != error)
-    {
-        fprintf(logfile, "unbzip2_data_block: failed to init, error %d\n", error);
-        return EIO;
-    }
-    
-    uc_stream.next_out = out_buf;
-    uc_stream.avail_out = out_len;
-
-    error = BZ2_bzDecompress(&uc_stream);
-    if (BZ_OK != error && BZ_STREAM_END != error)
-    {
-        fprintf(logfile, "unbzip2_data_block: failed to decompress, error %d\n", error);
-        return EIO;
-    }
-    
-    error = BZ2_bzDecompressEnd(&uc_stream);
-    if (BZ_OK != error)
-    {
-        fprintf(logfile, "unbzip2_data_block: failed to end, error %d\n", error);
-        return EIO;
-    }
-    
-    return 0;
-}    
-
-static int read_data_block(FILE *template_file)
-{
-    char inbuf[1024];
-    INT64 i = 0;
-    static INT64 template_offset = -1;
-    INT64 compressed_len = 0;
-    INT64 uncompressed_len = 0;
-    char *comp_buf = NULL;
-    int read_num = 0;
-    int error = 0;
-    int compress_type = COMP_GZIP; /* Sensible default */
-
-    /* If we've just started on this template file, find the first
-     * compressed data block */
-    if (-1 == template_offset)
-    {
-        fseek(template_file, 0, SEEK_SET);
-        fread(inbuf, sizeof(inbuf), 1, template_file);
-        for (i = 0; i < sizeof(inbuf); i++)
-        {
-            if (!strncmp(&inbuf[i], "DATA", 4) || !strncmp(&inbuf[i], "BZIP", 4))
-            {
-                template_offset = i;
-                break;
-            }
-        }
-        if (-1 == template_offset)
-        {
-            fprintf(logfile, "Unable to locate DATA block in template (offset %lld)\n",
-                    template_offset);
-            return EINVAL;
-        }    
-    }
-
-    /* Seek to the beginning of the (first/next) compressed data
-     * block, identify the compression type then decompress using the
-     * appropriate algorithm */
-    fseek(template_file, template_offset, SEEK_SET);
-    fread(inbuf, 16, 1, template_file);
-    if (!strncmp(inbuf, "DATA", 4))
-        compress_type = COMP_GZIP;
-    else if (!strncmp(inbuf, "BZIP", 4))
-        compress_type = COMP_BZIP2;
-    else
-    {
-        fprintf(logfile, "Unable to locate DATA block in template (offset %lld)\n",
-                template_offset);
-        return EINVAL;
-    }    
-    
-    compressed_len = read_le48((unsigned char *)&inbuf[4]);
-    uncompressed_len = read_le48((unsigned char *)&inbuf[10]);
-    comp_buf = calloc(1, compressed_len);
-    if (!comp_buf)
-    {
-        fprintf(logfile, "Unable to locate DATA block in template (offset %lld)\n",
-                template_offset);
-        return ENOMEM;
-    }
-    
-    zip_state.data_buf = calloc(1, uncompressed_len);
-    if (!zip_state.data_buf)
-    {
-        fprintf(logfile, "Unable to allocate %lld bytes for decompression\n",
-                uncompressed_len);
-        return ENOMEM;
-    }
-
-    read_num = fread(comp_buf, compressed_len, 1, template_file);
-    if (0 == read_num)
-    {
-        fprintf(logfile, "Unable to read %lld bytes for decompression\n",
-                uncompressed_len);
-        return EIO;
-    }
-
-    switch (compress_type)
-    {
-        case COMP_GZIP:
-            error = ungzip_data_block(comp_buf, compressed_len,
-                                      zip_state.data_buf, uncompressed_len);
-            break;
-        case COMP_BZIP2:
-            error = unbzip2_data_block(comp_buf, compressed_len,
-                                       zip_state.data_buf, uncompressed_len);
-            break;
-    }
-
-    if (error)
-    {
-        fprintf(logfile, "Unable to decompress data block, error %d\n", error);
-        return error;
-    }
-        
-    template_offset += compressed_len;
-    zip_state.buf_size = uncompressed_len;
-    zip_state.offset_in_curr_buf = 0;
-    free (comp_buf);
-    return 0;
-}
-
 static int skip_data_block(INT64 data_size, FILE *template_file)
 {
     int error = 0;
@@ -677,7 +494,7 @@ static int skip_data_block(INT64 data_size, FILE *template_file)
     {
         if (!zip_state.data_buf)
         {
-            error = read_data_block(template_file);
+            error = read_data_block(template_file, logfile, &zip_state);
             if (error)
             {
                 fprintf(logfile, "Unable to decompress template data, error %d\n",
@@ -712,7 +529,7 @@ static int parse_data_block(INT64 data_size, FILE *template_file,
     {
         if (!zip_state.data_buf)
         {
-            error = read_data_block(template_file);
+            error = read_data_block(template_file, logfile, &zip_state);
             if (error)
             {
                 fprintf(logfile, "Unable to decompress template data, error %d\n",
@@ -1100,7 +917,7 @@ int main(int argc, char **argv)
     logfile = stderr;
     outfile = stdout;
 
-    bzero(&zip_state, sizeof(zip_state));
+    memset(&zip_state, 0, sizeof(zip_state));
 
     while(1)
     {
